@@ -239,7 +239,7 @@ class CfnMicrosoftAD(
         def __init__(
             self,
             *,
-            subnet_ids: typing.List[builtins.str],
+            subnet_ids: typing.Sequence[builtins.str],
             vpc_id: builtins.str,
         ) -> None:
             '''
@@ -647,7 +647,7 @@ class CfnSimpleAD(
         def __init__(
             self,
             *,
-            subnet_ids: typing.List[builtins.str],
+            subnet_ids: typing.Sequence[builtins.str],
             vpc_id: builtins.str,
         ) -> None:
             '''
